@@ -403,7 +403,7 @@ def error_check_Main(arglist):
 
 def Main(arglist):
     """Start everything up!"""
-    local.setlocale(locale.LC_ALL, '')
+    locale.setlocale(locale.LC_ALL, '')
     parse_cmdlineoptions(arglist)
     check_action()
     cmdpairs = SetConnections.get_cmd_pairs(args, remote_schema, remote_cmd)
